@@ -18,35 +18,35 @@ package org.codehaus.plexus.interpolation;
 
 import java.util.Properties;
 
-import junit.framework.TestCase;
+import org.junit.jupiter.api.Test;
 
-public class PropertiesBasedValueSourceTest
-    extends TestCase
-{
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
 
-    public void testPropertyShouldReturnValueFromProperties()
-    {
+public class PropertiesBasedValueSourceTest {
+
+    @Test
+    public void testPropertyShouldReturnValueFromProperties() {
         Properties props = new Properties();
 
         String key = "key";
         String value = "value";
 
-        props.setProperty( key, value );
+        props.setProperty(key, value);
 
-        PropertiesBasedValueSource vs = new PropertiesBasedValueSource( props );
+        PropertiesBasedValueSource vs = new PropertiesBasedValueSource(props);
 
-        assertNotNull( vs.getValue( key ) );
+        assertNotNull(vs.getValue(key));
     }
 
-    public void testPropertyShouldReturnNullWhenPropertyMissing()
-    {
+    @Test
+    public void testPropertyShouldReturnNullWhenPropertyMissing() {
         Properties props = new Properties();
 
         String key = "key";
 
-        PropertiesBasedValueSource vs = new PropertiesBasedValueSource( props );
+        PropertiesBasedValueSource vs = new PropertiesBasedValueSource(props);
 
-        assertNull( vs.getValue( key ) );
+        assertNull(vs.getValue(key));
     }
-
 }
