@@ -15,17 +15,15 @@ package org.codehaus.plexus.interpolation.util;
  * limitations under the License.
  */
 
-import junit.framework.Assert;
-import junit.framework.TestCase;
+import org.junit.jupiter.api.Test;
 
-public class StringUtilsTest
-    extends TestCase
-{
-    public void testCapitalizeFirstLetter()
-        throws Exception
-    {
-        Assert.assertEquals( "Abc", StringUtils.capitalizeFirstLetter( "abc" ) );
-        Assert.assertEquals( "\u00cdce", StringUtils.capitalizeFirstLetter( "\u00edce" ) );
-        Assert.assertEquals( "X", StringUtils.capitalizeFirstLetter( "x" ) );
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
+public class StringUtilsTest {
+    @Test
+    public void testCapitalizeFirstLetter() throws Exception {
+        assertEquals("Abc", StringUtils.capitalizeFirstLetter("abc"));
+        assertEquals("\u00cdce", StringUtils.capitalizeFirstLetter("\u00edce"));
+        assertEquals("X", StringUtils.capitalizeFirstLetter("x"));
     }
 }
